@@ -61,14 +61,10 @@ void IconLabelLayoutPrivate::syncIconItem()
 void IconLabelLayoutPrivate::updateOrSyncIconItem()
 {
     Q_Q(IconLabelLayout);
-    if (updateIconItem()) {
-        if (q->isComponentComplete()) {
-            updateImplicitSize();
-            layout();
-        }
-    } else {
+    if (!updateIconItem()) {
         syncIconItem();
     }
+    q->relayout();
 }
 
 bool IconLabelLayoutPrivate::createLabelItem()
@@ -119,14 +115,10 @@ void IconLabelLayoutPrivate::syncLabelItem()
 void IconLabelLayoutPrivate::updateOrSyncLabelItem()
 {
     Q_Q(IconLabelLayout);
-    if (updateLabelItem()) {
-        if (q->isComponentComplete()) {
-            updateImplicitSize();
-            layout();
-        }
-    } else {
+    if (!updateLabelItem()) {
         syncLabelItem();
     }
+    q->relayout();
 }
 
 void IconLabelLayoutPrivate::updateImplicitSize()
@@ -318,7 +310,7 @@ void IconLabelLayout::setIconComponent(QQmlComponent *iconComponent)
 
     d->iconComponent = iconComponent;
     d->updateOrSyncIconItem();
-    emit iconComponentChanged();
+    Q_EMIT iconComponentChanged();
 }
 
 QQmlComponent *IconLabelLayout::labelComponent() const
@@ -336,7 +328,7 @@ void IconLabelLayout::setLabelComponent(QQmlComponent *labelComponent)
 
     d->labelComponent = labelComponent;
     d->updateOrSyncLabelItem();
-    emit labelComponentChanged();
+    Q_EMIT labelComponentChanged();
 }
 
 bool IconLabelLayout::hasIcon() const
@@ -353,7 +345,7 @@ void IconLabelLayout::setHasIcon()
     }
 
     d->hasIcon = !textOnly() && !d->icon.isEmpty();
-    emit hasIconChanged();
+    Q_EMIT hasIconChanged();
 }
 
 bool IconLabelLayout::hasLabel() const
@@ -370,7 +362,7 @@ void IconLabelLayout::setHasLabel()
     }
 
     d->hasLabel = !iconOnly() && !d->text.isEmpty();
-    emit hasLabelChanged();
+    Q_EMIT hasLabelChanged();
 }
 
 QQuickIcon IconLabelLayout::icon() const
@@ -390,7 +382,7 @@ void IconLabelLayout::setIcon(const QQuickIcon &icon)
     setHasIcon();
     d->updateOrSyncIconItem();
 
-    emit iconChanged();
+    Q_EMIT iconChanged();
 }
 
 QString IconLabelLayout::text() const
@@ -409,7 +401,7 @@ void IconLabelLayout::setText(const QString &text)
     d->text = text;
     setHasLabel();
     d->updateOrSyncLabelItem();
-    emit textChanged(text);
+    Q_EMIT textChanged(text);
 }
 
 QFont IconLabelLayout::font() const
@@ -429,7 +421,8 @@ void IconLabelLayout::setFont(const QFont &font)
     if (d->labelItem) {
         d->labelItem->setProperty("font", font);
     }
-    emit fontChanged(font);
+    d->updateOrSyncLabelItem();
+    Q_EMIT fontChanged(font);
 }
 
 QColor IconLabelLayout::color() const
@@ -450,7 +443,7 @@ void IconLabelLayout::setColor(const QColor &color)
         d->labelItem->setProperty("color", color);
     }
 
-    emit colorChanged();
+    Q_EMIT colorChanged();
 }
 
 QRectF IconLabelLayout::iconRect() const
@@ -469,7 +462,7 @@ void IconLabelLayout::setIconRect(const QRectF &rect)
     }
 
     d->iconRect = alignedRect;
-    emit iconRectChanged();
+    Q_EMIT iconRectChanged();
 }
 
 QRectF IconLabelLayout::labelRect() const
@@ -486,7 +479,7 @@ void IconLabelLayout::setLabelRect(const QRectF &rect)
     }
 
     d->labelRect = rect;
-    emit labelRectChanged();
+    Q_EMIT labelRectChanged();
 }
 
 qreal IconLabelLayout::availableWidth() const
@@ -504,7 +497,7 @@ void IconLabelLayout::setAvailableWidth()
     }
 
     d->availableWidth = newAvailableWidth;
-    emit availableWidthChanged();
+    Q_EMIT availableWidthChanged();
 }
 
 qreal IconLabelLayout::availableHeight() const
@@ -522,7 +515,7 @@ void IconLabelLayout::setAvailableHeight()
     }
 
     d->availableHeight = newAvailableHeight;
-    emit availableHeightChanged();
+    Q_EMIT availableHeightChanged();
 }
 
 qreal IconLabelLayout::spacing() const
@@ -539,7 +532,7 @@ void IconLabelLayout::setSpacing(qreal spacing)
     }
 
     d->spacing = spacing;
-    emit spacingChanged();
+    Q_EMIT spacingChanged();
     if (d->iconItem && d->labelItem) {
         relayout();
     }
@@ -559,7 +552,7 @@ void IconLabelLayout::setLeftPadding(qreal leftPadding)
     }
 
     d->leftPadding = leftPadding;
-    emit leftPaddingChanged();
+    Q_EMIT leftPaddingChanged();
     relayout();
 }
 
@@ -577,7 +570,7 @@ void IconLabelLayout::setRightPadding(qreal rightPadding)
     }
 
     d->rightPadding = rightPadding;
-    emit rightPaddingChanged();
+    Q_EMIT rightPaddingChanged();
     relayout();
 }
 
@@ -595,7 +588,7 @@ void IconLabelLayout::setTopPadding(qreal topPadding)
     }
 
     d->topPadding = topPadding;
-    emit topPaddingChanged();
+    Q_EMIT topPaddingChanged();
     relayout();
 }
 
@@ -613,7 +606,7 @@ void IconLabelLayout::setBottomPadding(qreal bottomPadding)
     }
 
     d->bottomPadding = bottomPadding;
-    emit bottomPaddingChanged();
+    Q_EMIT bottomPaddingChanged();
     relayout();
 }
 
@@ -631,7 +624,7 @@ void IconLabelLayout::setMirrored(bool mirrored)
     }
 
     d->mirrored = mirrored;
-    emit mirroredChanged();
+    Q_EMIT mirroredChanged();
     if (isComponentComplete()) {
         d->layout();
     }
@@ -658,7 +651,7 @@ void IconLabelLayout::setAlignment(Qt::Alignment alignment)
         d->labelItem->setProperty("horizontalAlignment", halign);
         d->labelItem->setProperty("verticalAlignment", valign);
     }
-    emit alignmentChanged();
+    Q_EMIT alignmentChanged();
     if (isComponentComplete()) {
         d->layout();
     }
@@ -679,16 +672,16 @@ void IconLabelLayout::setDisplay(IconLabelLayout::Display display)
     }
 
     d->display = display;
-    emit displayChanged();
+    Q_EMIT displayChanged();
 
     if (oldDisplay == iconOnly()) {
-        emit iconOnlyChanged();
+        Q_EMIT iconOnlyChanged();
     } else if (oldDisplay == textOnly()) {
-        emit textOnlyChanged();
+        Q_EMIT textOnlyChanged();
     } else if (oldDisplay == textBesideIcon()) {
-        emit textBesideIconChanged();
+        Q_EMIT textBesideIconChanged();
     } else if (oldDisplay == textUnderIcon()) {
-        emit textUnderIconChanged();
+        Q_EMIT textUnderIconChanged();
     }
 
     setHasIcon();
@@ -738,20 +731,14 @@ void IconLabelLayout::componentComplete()
     relayout();
 }
 
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-void IconLabelLayout::geometryChanged(const QRectF &newGeometry, const QRectF &oldGeometry)
-#else
 void IconLabelLayout::geometryChange(const QRectF &newGeometry, const QRectF &oldGeometry)
-#endif
 {
     if (newGeometry != oldGeometry) {
         setAvailableWidth();
         setAvailableHeight();
         relayout();
     }
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    QQuickItem::geometryChanged(newGeometry, oldGeometry);
-#else
     QQuickItem::geometryChange(newGeometry, oldGeometry);
-#endif
 }
+
+#include "moc_iconlabellayout.cpp"
