@@ -11,6 +11,7 @@ class QQuickIconPrivate : public QSharedData
 public:
     QString name;
     QUrl source;
+    QUrl resolvedSource; // UNUSED: needed to keep compatibility with Qt's QQuickIcon
     int width = 0;
     int height = 0;
     QColor color = Qt::transparent;
@@ -238,3 +239,5 @@ QQuickIcon QQuickIcon::resolve(const QQuickIcon &other) const
 
     return resolved;
 }
+
+#include "moc_qquickicon_p.cpp"
